netapp_ontap.models.application_statistics API documentation
Description: Copyright &copy; 2020 NetApp Inc. All rights reserved.

# Module `netapp_ontap.models.application_statistics`

Copyright © 2020 NetApp Inc. All rights reserved.

## Classes

`class ApplicationStatisticsSchema (*, only: typing.Union = None, exclude: typing.Union = (), many: bool = False, context: typing.Dict = None, load_only: typing.Union = (), dump_only: typing.Union = (), partial: typing.Union = False, unknown: str = None)`

  The fields of the ApplicationStatistics object

  ### Ancestors

  - netapp_ontap.resource.ResourceSchema
  - marshmallow.schema.Schema
  - marshmallow.base.SchemaABC

  ### Class variables

  `components GET`

    The components field of the application_statistics.

  `iops GET POST PATCH`

    The iops field of the application_statistics.

  `latency GET POST PATCH`

    The latency field of the application_statistics.

  `shared_storage_pool GET`

    An application is considered to use a shared storage pool if storage elements for multiple components reside on the same aggregate.

  `snapshot GET POST PATCH`

    The snapshot field of the application_statistics.

  `space GET POST PATCH`

    The space field of the application_statistics.

  `statistics_incomplete GET`

    If not all storage elements of the application are currently available, the returned statistics might only include data from those elements that were available.